package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````H)P$"#0```",P@```````#0`(``)
M`"@`'0`<``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(0+4`
M`$"U```%`````!````$```#DO@``Y$X%".1.!0AT`@``P!(```8`````$```
M`@```/B^``#X3@4(^$X%"/@```#X````!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&10M```4#0%"%`T!0@T````-`````0`
M```$````4>5T9```````````````````````````!@````0```!2Y71DY+X`
M`.1.!0CD3@4('`$``!P!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@````\````$````%`````,```!'
M3E4`I/T?OQ32L,XI7+#!KWQDP<3Y@1EA````<P````L``````````````$,`
M````````2````$<``````````````%H````^````.0```$L````$````6```
M```````Q````7P```%4```!J````;````&<````%````+```````````````
M*@```&,```!&``````````````!D````20```&4````)`````````%(```!R
M`````@```$T`````````'P````````!P`````````%$```!N````````````
M``!F````*````$\````Z``````````````!O````-0```$````!%````````
M```````3`````````#\``````````````",`````````'````#`````,````
M,@```"D```!4``````````````!;````4````#P```!>````3````#L````T
M``````````T```````````````````!6````;0````````!$````70```$(`
M```]````)P````$`````````````````````````````````````````````
M````````````````````````````3@``````````````````````````````
M#P`````````0````%0```&`````````````````````4```````````````2
M`````````!D`````````````````````````60````````!7`````````&@`
M`````````````!$````````````````````;`````````"8```!I````)```
M``@`````````+P```"4````.````'0````````!A````(0`````````:````
M"@``````````````00`````````S````'@```"X`````````<0```%P`````
M````2@````<``````````````&L`````````````````````````````````
M```B```````````````8`````````#8`````````*P``````````````````
M```````7`````````!8`````````4P`````````&````````````````````
M8@```#<````#````(````"T````X````)0```$X````(````"``````0$`0E
M0`2`J!$``:*&0:A````"2R@$*3BB,D>*!`R(3@```%``````````````````
M``!3````50```%8`````````5P```%@`````````60```%H```!;````````
M`%P```````````````````!=````8```````````````80```&,```!D````
M9@````````!H````:P````````!M````;@```&\```!P`````````,C5LG%9
MZ.WLYO\PHL[>1RVCX/M)ZM/O#J?=HVLOQ9NVV\WCGH?YG(%K"4/6#3J7"\6)
M!9`-%.*>(?_D#K(!BV_$N9Q`:W^:?'^IG)MNQ=\?V7%8'+OCDGS49-1\K4OC
MP#)BV^WAIP(*9J_,9F`6R5E[\$IKXD?&`4-%U>Q'[#,Z?4&.Q</E/RSRV],=
M^J%L8+F-\0X`````````````````````^`(`````````````$@```$8#````
M`````````!(```"Q```````````````2````E`,`````````````$@```'\#
M`````````````!(```"A`0`````````````2````>@(`````````````$@``
M`!$``````````````"`````@```````````````@````A0,`````````````
M$@```(T!`````````````!(````T!``````````````2````;@$`````````
M````$@```(`!`````````````!(```!?`P`````````````2````+P,`````
M````````$@````D#`````````````!(````L`@`````````````2````_0``
M````````````$@```!P"`````````````!(```"P`P`````````````2````
MR@$`````````````$@```!@$`````````````!(```#7`@`````````````2
M````$0,`````````````$@```)@"`````````````!(```#J`0``````````
M```2````I@$`````````````$@```#4"`````````````!(````^!```````
M```````2````"@0`````````````$@```"\!`````````````!(```#+`P``
M```````````2````-```````````````$@```-,#`````````````!(```!=
M`0`````````````2````R```````````````$@```/@#`````````````!(`
M``#$`P`````````````2````\0,`````````````$@```*D#````````````
M`!(```!X`P`````````````2````_`0`````````````$@```$$!````````
M`````!(```#A`P`````````````2````7`(`````````````$@```%8#````
M`````````!(```#K`@`````````````2````3@(`````````````$@```+<#
M`````````````!(```"1`@`````````````2````JP$`````````````$@``
M`&<#`````````````!(```"^`P`````````````2````H@,`````````````
M$@```.P``````````````!(```!"```````````````2````Z`,`````````
M````$@````($`````````````!(```#7```````````````2````_@$`````
M````````$@```(4"`````````````!(```!0`0`````````````2````C0,`
M````````````$@```$X#`````````````!(```#Q`@`````````````2````
M'0$`````````````$@```$,"`````````````!(```!4```````````````2
M````FP,`````````````$@```-@!`````````````!(```!C````````````
M```2````$00`````````````$@```(\``````````````!(```!!`P``````
M```````2````>```````````````$@````L!`````````````!(```"W`0``
M()@$"``````2````G00``.#7!`@$````$0`0`&8%``#@V@0(;ED``!$`$`!P
M!0``L\$$")0'```2``X`G`4``&NF!`@<`@``$@`.`)<$``"HUP0(`````!(`
M#P`L!```8%$%"`0````A`!H`;P0``&RB!`@-````$@`.`#4%``#`U@0(6@``
M`!(`#@"@````\)D$"``````2````(`4``#Q1!0@`````$``9`"(%```\404(
M`````"``&0`K!```8%$%"`0````A`!H`C00``+#6!`@%````$@`.`(\%``!Y
MH@0(O0(``!(`#@"Z!```AZ@$"%,````2``X`*@0``&!1!0@$````$0`:`"4$
M``"MTP0(SP(``!(`#@#J!```?[\$"#L````2``X`!04``,'*!`AH````$@`.
M`%X$``!8404(`````!``\?]J!```I&$%"``````0`/'_I`0``$_.!`CR!```
M$@`.`"`#``#DUP0(!````!$`$``F!0``H)P$"``````2``X`R`0``'&A!`C[
M````$@`.`-X$``!RI00(^0```!(`#@`1!0``5%$%"`0````1`!D`:@(``."9
M!`@`````$@```(`$```VI00(/````!(`#@!7!```6%$%"``````0`/'_804`
M`%!1!0@$````$0`9`$4%``#PS00(7P```!(`#@`M!0``6)T$"$`````2``X`
MHP(``&11!0@3````$0`:`'T%``",P`0()P$``!(`#@`O!0``<)<$"``````2
M``P``&QI8G!E<FPN<V\N-2XQ,`!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T
M97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R
M;%]S>7-?:6YI=#,`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E
M<W1R=6-T;W)?>`!097)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`
M4&5R;%])8W5R<W1A8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R
M;V%K7VYO8V]N=&5X=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`
M4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I
M;G1E9%]P='(`4&5R;%]S=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W
M6%-?9FQA9W,`4&5R;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?
M265V86Q?<F]O=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F
M;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E
M<FQ?1V1O7W5N9'5M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P
M='(`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R
M;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H
M<F5A9"YS;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?
M97)R;F]?;&]C871I;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?24]?<W1D
M:6Y?=7-E9`!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-P<FEN=&8`<W1R;F-M
M<`!C;&]S961I<@!S=')N8W!Y`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK
M9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE
M;@!M96US970`<W1R<W1R`')M9&ER`&UE;6-P>0!O<&5N9&ER`%]?8W1Y<&5?
M8E]L;V,`9V5T=6ED`')E861L:6YK`&5X96-V<`!R96%D9&ER-C0`;65M;6]V
M90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?
M7WAS=&%T-C0`7U]L>'-T870V-`!L:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?
M;&EB8U]C<W5?9FEN:0!?9G!?:'<`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A
M<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'-I>F5?
M;&]A9%]M95\R`%]?9&%T85]S=&%R=`!X<U]I;FET`%]?;&EB8U]C<W5?:6YI
M=`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`;F%M95]L;V%D7VUE7S(`
M<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,P!'3$E"0U\R+C,N,@!'
M3$E"0U\R+C(`1TQ)0D-?,BXP``````(``P````,``P````````````,````$
M```````#``4`!@`````````#`````P`"``(```````,````$``,````#````
M!P``````!``#``,``P`#``,````#`````P`"`````P`#````"``#``,`````
M``,``P````````````,``P`&``````````,```````,````#``````````$`
M`0`!``$``0`#``$``0````$``0`#``$``0`!``,``0`!``$``0`!``$``0`!
M``$``0`!`````0`!``$``0`!`````0`!``$`!0`6`P``$````&`````4:6D-
M```(`*D%```0````$VEI#0``!P"S!0``$````'(9:0D```4`O04``!`````2
M:6D-```$`,D%```0````$&EI#0```P#3!0````````$``@#'`@``$```````
M```2:6D-```&`,D%```0````$&EI#0```@#3!0```````/!/!0@&"```8%$%
M"`5>``!D404(!7````!0!0@'`0``!%`%"`<"```(4`4(!P,```Q0!0@'!```
M$%`%"`<%```44`4(!P8``!A0!0@'!P``'%`%"`=.```@4`4(!P@``"10!0@'
M"@``*%`%"`<+```L4`4(!PP``#!0!0@'#0``-%`%"`<.```X4`4(!P\``#Q0
M!0@'$```0%`%"`<1``!$4`4(!Q(``$A0!0@'$P``3%`%"`<4``!04`4(!Q4`
M`%10!0@'%@``6%`%"`<7``!<4`4(!Q@``&!0!0@'&0``9%`%"`<:``!H4`4(
M!QL``&Q0!0@''```<%`%"`<=``!T4`4(!QX``'A0!0@''P``?%`%"`<@``"`
M4`4(!R$``(10!0@'(@``B%`%"`<C``",4`4(!VH``)!0!0@'5P``E%`%"`<D
M``"84`4(!R4``)Q0!0@')@``H%`%"`<G``"D4`4(!R@``*A0!0@'*0``K%`%
M"`<J``"P4`4(!RL``+10!0@'+```N%`%"`<M``"\4`4(!RX``,!0!0@'+P``
MQ%`%"`<P``#(4`4(!S$``,Q0!0@',@``T%`%"`<S``#44`4(!S0``-A0!0@'
M-0``W%`%"`<V``#@4`4(!S<``.10!0@'.```Z%`%"`<Y``#L4`4(!SH``/!0
M!0@'.P``]%`%"`<\``#X4`4(!ST``/Q0!0@'/@```%$%"`<_```$404(!T``
M``A1!0@'00``#%$%"`="```0404(!T,``!11!0@'1```&%$%"`=%```<404(
M!T8``"!1!0@'1P``)%$%"`=(```H404(!TD``"Q1!0@'2@``,%$%"`=+```T
M404(!TP``#A1!0@'30``58GE4X/L!.@`````6X'#>+@``(N3_/___X72=`7H
MG@```.B9!0``Z.0_``!86\G#_S7X3P4(_R7\3P4(`````/\E`%`%"&@`````
MZ>#_____)010!0AH"````.G0_____R4(4`4(:!````#IP/____\E#%`%"&@8
M````Z;#_____)1!0!0AH(````.F@_____R444`4(:"@```#ID/____\E&%`%
M"&@P````Z8#_____)1Q0!0AH.````.EP_____R4@4`4(:$````#I8/____\E
M)%`%"&A(````Z5#_____)2A0!0AH4````.E`_____R4L4`4(:%@```#I,/__
M__\E,%`%"&A@````Z2#_____)310!0AH:````.D0_____R4X4`4(:'````#I
M`/____\E/%`%"&AX````Z?#^____)4!0!0AH@````.G@_O___R5$4`4(:(@`
M``#IT/[___\E2%`%"&B0````Z<#^____)4Q0!0AHF````.FP_O___R504`4(
M:*````#IH/[___\E5%`%"&BH````Z9#^____)5A0!0AHL````.F`_O___R5<
M4`4(:+@```#I</[___\E8%`%"&C`````Z6#^____)610!0AHR````.E0_O__
M_R5H4`4(:-````#I0/[___\E;%`%"&C8````Z3#^____)7!0!0AHX````.D@
M_O___R5T4`4(:.@```#I$/[___\E>%`%"&CP````Z0#^____)7Q0!0AH^```
M`.GP_?___R6`4`4(:``!``#IX/W___\EA%`%"&@(`0``Z=#]____)8A0!0AH
M$`$``.G`_?___R6,4`4(:!@!``#IL/W___\ED%`%"&@@`0``Z:#]____)910
M!0AH*`$``.F0_?___R684`4(:#`!``#I@/W___\EG%`%"&@X`0``Z7#]____
M):!0!0AH0`$``.E@_?___R6D4`4(:$@!``#I4/W___\EJ%`%"&A0`0``Z4#]
M____):Q0!0AH6`$``.DP_?___R6P4`4(:&`!``#I(/W___\EM%`%"&AH`0``
MZ1#]____);A0!0AH<`$``.D`_?___R6\4`4(:'@!``#I\/S___\EP%`%"&B`
M`0``Z>#\____)<10!0AHB`$``.G0_/___R7(4`4(:)`!``#IP/S___\ES%`%
M"&B8`0``Z;#\____)=!0!0AHH`$``.F@_/___R744`4(:*@!``#ID/S___\E
MV%`%"&BP`0``Z8#\____)=Q0!0AHN`$``.EP_/___R7@4`4(:,`!``#I8/S_
M__\EY%`%"&C(`0``Z5#\____)>A0!0AHT`$``.E`_/___R7L4`4(:-@!``#I
M,/S___\E\%`%"&C@`0``Z2#\____)?10!0AHZ`$``.D0_/___R7X4`4(:/`!
M``#I`/S___\E_%`%"&CX`0``Z?#[____)0!1!0AH``(``.G@^____R4$404(
M:`@"``#IT/O___\E"%$%"&@0`@``Z<#[____)0Q1!0AH&`(``.FP^____R40
M404(:"`"``#IH/O___\E%%$%"&@H`@``Z9#[____)1A1!0AH,`(``.F`^___
M_R4<404(:#@"``#I</O___\E(%$%"&A``@``Z6#[____)211!0AH2`(``.E0
M^____R4H404(:%`"``#I0/O___\E+%$%"&A8`@``Z3#[____)3!1!0AH8`(`
M`.D@^____R4T404(:&@"``#I$/O___\E.%$%"&AP`@``Z0#[__\Q[5Z)X8/D
M\%!44FBPU@0(:,#6!`A15FBMTP0(Z$_\___TD)"0D)"0D)"0D)"0D)!5B>53
M@^P$@#UX404(`'4_N/!.!0B+%7Q1!0@M[$X%",'X`HU8_SG:<QZ-M@````!"
MB15\404(_Q25[$X%"(L5?%$%"#G:<NC&!7A1!0@!6%M=PXVV`````(V\)P``
M``!5B>6#[`B+%?1.!0B%TG03N`````"%P'0*@^P,:/1.!0C_T,G#D)"058GE
M@^P8QT7TZ-<$"(/L#&H`Z,'^__^#Q!"+`(/L#%#HH_O__X/$$/]U]&C@F00(
M:/+7!`A0Z&W^__^#Q!#)PU6)Y5.!["00``"+10R)A>3O__^+11")A>#O__]E
MH10```")1?0QP+@.V`0(@^P$:/\/``"-E?3O__]24.B'_?__@\00B87P[___
M@[WP[___`'X8BX7P[___2(J$!?3O__^$P'4&_XWP[___@[WP[___`'Y9BX7P
M[___@^P$4&HOC87T[___4.B<_?__@\00A<!T.HN=\.___X/L#&H`Z/7]__^#
MQ!"+`(/L#%#HU_K__X/$$%.-E?3O__]2_[7D[___4.@@_/__@\00ZS.#[`QJ
M`.C!_?__@\00BP"#[`Q0Z*/Z__^#Q!"#[`3_M>#O____M>3O__]0Z&OZ__^#
MQ!"+1?1E,P44````=`7H9_S__XM=_,G#58GE5U93@^P<BWT(A?]T":%@404(
MA<!U![@`````ZW.)^^L!0XH#A,!T!HH#/#UU\XG:B?B)T2G!B4WDBS5@404(
MZT2+1>2#[`105U/HT/S__X/$$(7`=2R+1>2-!`.*`#P]=2")\J%@404(B=$I
MP8G(P?@"B<*+10R)$(M%Y$"-!`/K#H/&!(L>A=MUMK@`````C67T@\0`6UY?
M7<-5B>6#[!B#[`B-1?10_W4(Z$W___^#Q!#)PU6)Y5=64X/L'(MU#(H&/#UU
M`4:#[`Q6Z,[Z__^#Q!")1>2#[`B-1>!0_W4(Z!?___^#Q!")PX7;=#"#[`Q3
MZ*?Z__^#Q!`[1>0/@M@```"*!H@#B@.$P`^5P$-&A,!U[[@`````Z5$!``"+
M'6!1!0B_`````.L$@\,$1XL#A<!U]J&@804(A<!T,HU'`L'@`HG"H6!1!0B#
M[`A24.@Y^/__@\00HV!1!0BA8%$%"(7`=5JX_____^G_````QP6@804(`0``
M`(U'`L'@`H/L#%#HM?K__X/$$(G#A=MU"KC_____Z=,```")^(T4A0````"A
M8%$%"(/L!%)04^@)^___@\00B1U@404(ZP&0H6!1!0B)^D+!X@(!T,<`````
M`(GXB47@ZP&0BUT(ZP%#B@.$P'0&B@,\/77SH6!1!0B+5>#!X@*-/!")VHM%
M"(G1*<&)R`-%Y(/``H/L#%#H*/K__X/$$(D'BP>%P'4'N/_____K1Z%@404(
MBU7@P>("`="+&.L!0XM%"(H`B`.*`X3`#Y7`_T4(A,!T!HH#/#UUY,8#/4.*
M!H@#B@.$P`^5P$-&A,!U[[@`````C67T@\0`6UY?7<-5B>53@^P4ZR&A8%$%
M"(M5],'B`HT<$(U#!(L`B0.+`X7`=`6#PP3K[I"#[`B-1?10_W4(Z$G]__^#
MQ!"%P'7)BUW\R<-5B>6![!@@``!EH10```")1?0QP,>%[-___P````#H3/;_
M_[HAV`0(:"W8!`A04HV%\^___U#H%/;__X/$$(F%Z-___X.]Z-___P!Y"K@`
M````Z9$```"-A?/O__^#[`1H`!```(V5\M___U)0Z'WY__^#Q!")A>C?__^#
MO>C?__\`>0>X`````.M=BX7HW___0(/L#%#HY/C__X/$$(F%[-___X.][-__
M_P!U![@`````ZS2+A>C?__^#[`10C87RW___4/^U[-___^CO]___@\00BX7H
MW___`X7LW___Q@``BX7LW___BU7T93,5%````'0%Z*;X___)PU6)Y8/L".CZ
M_O__R<-5B>6![#@0``"+10B)A=3O__^+10R)A=#O__]EH10```")1?0QP(/L
M#&@QV`0(Z*#\__^#Q!")A>3O__^A1%$%"(/L"%#_M=3O___H%_C__X/$$(7`
M="&#[`C_M=3O__]H.M@$".B#_/__@\00BX74[___Z3("``"#[`S_M=3O___H
M4??__X/$$(F%[.___Z%(404(@^P(4/^UT.___^@4^/__@\00B87P[___Z=`!
M``"+A?#O__^*`(3`=0K'A?#O__]'V`0(@[WD[___`'0Y@^P(_[7P[____[7D
M[___Z//X__^#Q!"%P'4>H4A1!0B#[`A0:@#HO/?__X/$$(F%\.___^EX`0``
M@^P,_[7P[___Z,#V__^#Q!")A>CO___K%?^-Z.___XN%Z.___P.%\.___\8`
M`(N%Z.___T@#A?#O__^*$*%$404(B@`XPG31BX7H[___0`.%[.___SW_#P``
M?B&#[`C_M=3O__]H.M@$".AU^___@\00BX74[___Z20!``"+%411!0BX2=@$
M"(/L#/^UU.___U+_M?#O__]0C87T[___4.B9\___@\0@@^P,:@#H_/?__X/$
M$(L`@^P,4.C>]/__@\00@^P,4.@"]___@\00C97T[___@^P(4%+HOS(``(/$
M$(7`=7F#[`QJ`.B^]___@\00BP"#[`Q0Z*#T__^#Q!"#[`Q0Z,3V__^#Q!"+
M0!`E`/```#T`@```=4.#[`AJ`8V%].___U#HX?3__X/$$(7`=2N#[`B-A?3O
M__]0:#K8!`CHG/K__X/$$(/L#(V%].___U#H1/?__X/$$.M"H4A1!0B#[`A0
M:@#H/_;__X/$$(F%\.___X.]\.___P`/A2/^__^#[`C_M=3O__]H.M@$".A,
M^O__@\00BX74[___BU7T93,5%````'0%Z-SU___)PU6)Y8/L$(M%"(E%_(M%
M"(E%^.L:BT7XBA"A1%$%"(H`.,)U!XM%^$")1?S_1?B+1?B*`(3`==V+1?S)
MPU6)Y5.#[`2#?0@`=`F+10B*`(3`=16#[`QH1]@$".B+]O__@\00Z<D```"#
M[`S_=0CHJ/3__X/$$$B)PP-=".L!2SM="'80BA.A1%$%"(H`.,)T[>L!2SM=
M"'8-BA.A1%$%"(H`.,)U[3M="'4RBA.A1%$%"(H`.,)U$H/L#&A'V`0(Z";V
M__^#Q!#K9Z%$404(@^P,4.@3]O__@\00ZU1+.UT(=@V*$Z%$404(B@`XPG3M
MB=J+10B)T2G!B<B#P`(]`!```'8'N`````#K)8G:BT4(B=$IP8G(0(/L!%#_
M=0AHH%$%".@R\O__@\00N*!1!0B+7?S)PU6)Y5=64X/L/&6A%````(E%Y#'`
MC47"NOS8!`B[(@```(G!@^$"A<ET#V:+"F:)"(/``H/"`H/K`HG9P>D"B<>)
MUO.EB?*)^+D`````B=Z#Y@*%]G0+9HLT"F:)-`B#P0*#XP&%VW0&BA0*B!0(
M@^P,:%#8!`CH1OK__X/$$(/L#&A@V`0(Z#;Z__^#Q!"#[`QH,=@$".@F^O__
M@\00@^P,:&S8!`CH%OK__X/$$(/L#&AVV`0(Z`;Z__^#Q!"#[`QH@-@$".CV
M^?__@\00@^P,:#K8!`CHYOG__X/$$(/L#&B*V`0(Z-;Y__^#Q!"#[`QHD]@$
M".C&^?__@\00@^P,:)[8!`CHUO?__X/$$(E%O(-]O`!T$X/L"/]UO&AVV`0(
MZ-3W__^#Q!"#[`QHK]@$".BJ]___@\00B46\@WV\`'03@^P(_W6\:,'8!`CH
MJ/?__X/$$(/L#&C,V`0(Z'[W__^#Q!")1;R#?;P`=!6#[`C_=;QH,=@$".A\
M]___@\00ZV>#[`QHW-@$".A0]___@\00B46\@WV\`'05@^P(_W6\:&S8!`CH
M3O?__X/$$.LYC47"@\`1B46\@^P$:@IH[=@$"/]UO.B8\___@\00A<!U%XM%
MO(/`"H/L"%!H;-@$".@3]___@\00@^P(:/C8!`AH4-@$".C^]O__@\00BT7D
M93,%%````'0%Z)3R__^-9?2#Q`!;7E]=PU6)Y8/L&*%,404(@_C_=3R#[`QH
M;-@$".BH]O__@\00B47T@WWT`'09BT7TB@"$P'00BT7TB@`\,'0'N`$```#K
M!;@`````HTQ1!0BA3%$%",G#58GE4X'L<`$``(M%"(/`'(E%],=%^`````#K
M18M%](L`B47P@T7T!(M%^(M5\(G1P>$8BU7PP>((@>(``/\`"=&+5?#!Z@B!
MX@#_```)T8M5\,'J&`G*B92%F/[___]%^(-]^`]^M<=%^!````#K7HM%^(M5
M^(/J`XN,E9C^__^+5?B#Z@B+E)68_O__,=&+5?B#Z@Z+E)68_O__,=&+5?B#
MZA"+E)68_O__,<J)E(68_O__BT7XBU7XBY25F/[__\'*'XF4A9C^____1?B#
M??A/?IR+10B+`(E%[(M%"(M`!(E%Z(M%"(M`"(E%Y(M%"(M`#(E%X(M%"(M`
M$(E%W(V%F/[__XE%V(M%[(G!P<D;BT7DBU7H(<*+1>CWT"-%X`G0C00!B<(#
M5=R+1=B+`(T$`@69>8):B47P@T78!,%-Z`*+1?")P<')&XM%Z(M5["'"BT7L
M]]`C1>0)T(T$`8G"`U7@BT78BP"-!`(%F7F"6HE%W(-%V`3!3>P"BT7<B<'!
MR1N+1>R+5?`APHM%\/?0(T7H"="-!`&)P@-5Y(M%V(L`C00"!9EY@EJ)1>"#
M1=@$P4WP`HM%X(G!P<D;BT7PBU7<(<*+1=SWT"-%[`G0C00!B<(#5>B+1=B+
M`(T$`@69>8):B47D@T78!,%-W`*+1>2)P<')&XM%W(M5X"'"BT7@]]`C1?`)
MT(T$`8G"`U7LBT78BP"-!`(%F7F"6HE%Z(-%V`3!3>`"BT7HB<'!R1N+1>"+
M5>0APHM%Y/?0(T7<"="-!`&)P@-5\(M%V(L`C00"!9EY@EJ)1>R#1=@$P4WD
M`HM%[(G!P<D;BT7DBU7H(<*+1>CWT"-%X`G0C00!B<(#5=R+1=B+`(T$`@69
M>8):B47P@T78!,%-Z`*+1?")P<')&XM%Z(M5["'"BT7L]]`C1>0)T(T$`8G"
M`U7@BT78BP"-!`(%F7F"6HE%W(-%V`3!3>P"BT7<B<'!R1N+1>R+5?`APHM%
M\/?0(T7H"="-!`&)P@-5Y(M%V(L`C00"!9EY@EJ)1>"#1=@$P4WP`HM%X(G!
MP<D;BT7PBU7<(<*+1=SWT"-%[`G0C00!B<(#5>B+1=B+`(T$`@69>8):B47D
M@T78!,%-W`*+1>2)P<')&XM%W(M5X"'"BT7@]]`C1?`)T(T$`8G"`U7LBT78
MBP"-!`(%F7F"6HE%Z(-%V`3!3>`"BT7HB<'!R1N+1>"+5>0APHM%Y/?0(T7<
M"="-!`&)P@-5\(M%V(L`C00"!9EY@EJ)1>R#1=@$P4WD`HM%[(G!P<D;BT7D
MBU7H(<*+1>CWT"-%X`G0C00!B<(#5=R+1=B+`(T$`@69>8):B47P@T78!,%-
MZ`*+1?")P<')&XM%Z(M5["'"BT7L]]`C1>0)T(T$`8G"`U7@BT78BP"-!`(%
MF7F"6HE%W(-%V`3!3>P"BT7<B<'!R1N+1>R+5?`APHM%\/?0(T7H"="-!`&)
MP@-5Y(M%V(L`C00"!9EY@EJ)1>"#1=@$P4WP`HM%X(G!P<D;BT7PBU7<(<*+
M1=SWT"-%[`G0C00!B<(#5>B+1=B+`(T$`@69>8):B47D@T78!,%-W`*+1>2)
MP<')&XM%W(M5X"'"BT7@]]`C1?`)T(T$`8G"`U7LBT78BP"-!`(%F7F"6HE%
MZ(-%V`3!3>`"BT7HB<'!R1N+1>"+5>0APHM%Y/?0(T7<"="-!`&)P@-5\(M%
MV(L`C00"!9EY@EJ)1>R#1=@$P4WD`HM%[(G!P<D;BT7DBU7H(<*+1>CWT"-%
MX`G0C00!B<(#5=R+1=B+`(T$`@69>8):B47P@T78!,%-Z`*+1?")P<')&XM%
MZ(M5["'"BT7L]]`C1>0)T(T$`8G"`U7@BT78BP"-!`(%F7F"6HE%W(-%V`3!
M3>P"BT7<B<'!R1N+1>R+5?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(%H>O9;HE%
MX(-%V`3!3?`"BT7@B<'!R1N+1?"+5=PQT#-%[(T$`8G"`U7HBT78BP"-!`(%
MH>O9;HE%Y(-%V`3!3=P"BT7DB<'!R1N+1=R+5>`QT#-%\(T$`8G"`U7LBT78
MBP"-!`(%H>O9;HE%Z(-%V`3!3>`"BT7HB<'!R1N+1>"+5>0QT#-%W(T$`8G"
M`U7PBT78BP"-!`(%H>O9;HE%[(-%V`3!3>0"BT7LB<'!R1N+1>2+5>@QT#-%
MX(T$`8G"`U7<BT78BP"-!`(%H>O9;HE%\(-%V`3!3>@"BT7PB<'!R1N+1>B+
M5>PQT#-%Y(T$`8G"`U7@BT78BP"-!`(%H>O9;HE%W(-%V`3!3>P"BT7<B<'!
MR1N+1>R+5?`QT#-%Z(T$`8G"`U7DBT78BP"-!`(%H>O9;HE%X(-%V`3!3?`"
MBT7@B<'!R1N+1?"+5=PQT#-%[(T$`8G"`U7HBT78BP"-!`(%H>O9;HE%Y(-%
MV`3!3=P"BT7DB<'!R1N+1=R+5>`QT#-%\(T$`8G"`U7LBT78BP"-!`(%H>O9
M;HE%Z(-%V`3!3>`"BT7HB<'!R1N+1>"+5>0QT#-%W(T$`8G"`U7PBT78BP"-
M!`(%H>O9;HE%[(-%V`3!3>0"BT7LB<'!R1N+1>2+5>@QT#-%X(T$`8G"`U7<
MBT78BP"-!`(%H>O9;HE%\(-%V`3!3>@"BT7PB<'!R1N+1>B+5>PQT#-%Y(T$
M`8G"`U7@BT78BP"-!`(%H>O9;HE%W(-%V`3!3>P"BT7<B<'!R1N+1>R+5?`Q
MT#-%Z(T$`8G"`U7DBT78BP"-!`(%H>O9;HE%X(-%V`3!3?`"BT7@B<'!R1N+
M1?"+5=PQT#-%[(T$`8G"`U7HBT78BP"-!`(%H>O9;HE%Y(-%V`3!3=P"BT7D
MB<'!R1N+1=R+5>`QT#-%\(T$`8G"`U7LBT78BP"-!`(%H>O9;HE%Z(-%V`3!
M3>`"BT7HB<'!R1N+1>"+5>0QT#-%W(T$`8G"`U7PBT78BP"-!`(%H>O9;HE%
M[(-%V`3!3>0"BT7LB<'!R1N+1>2+5>@QT#-%X(T$`8G"`U7<BT78BP"-!`(%
MH>O9;HE%\(-%V`3!3>@"BT7PB<'!R1N+1>B+5>PQT#-%Y(T$`8G"`U7@BT78
MBP"-!`(%H>O9;HE%W(-%V`3!3>P"BT7<B<'!R1N+1>R+5?`QT#-%Z(T$`8G"
M`U7DBT78BP"-!`(%H>O9;HE%X(-%V`3!3?`"BT7@B<'!R1N+1?"+5=PQT#-%
M[(T$`8G"`U7HBT78BP"-!`(%H>O9;HE%Y(-%V`3!3=P"BT7DB</!RQN+1?"+
M5=P)T"-%X(M5\(M-W"'*"="-!`.)P@-5[(M%V(L`C00"+21#Y'")1>B#1=@$
MP4W@`HM%Z(G#P<L;BT7<BU7@"=`C1>2+5=R+3>`AR@G0C00#B<(#5?"+1=B+
M`(T$`BTD0^1PB47L@T78!,%-Y`*+1>R)P\'+&XM%X(M5Y`G0(T7HBU7@BTWD
M(<H)T(T$`XG"`U7<BT78BP"-!`(M)$/D<(E%\(-%V`3!3>@"BT7PB</!RQN+
M1>2+5>@)T"-%[(M5Y(M-Z"'*"="-!`.)P@-5X(M%V(L`C00"+21#Y'")1=R#
M1=@$P4WL`HM%W(G#P<L;BT7HBU7L"=`C1?"+5>B+3>PAR@G0C00#B<(#5>2+
M1=B+`(T$`BTD0^1PB47@@T78!,%-\`*+1>")P\'+&XM%[(M5\`G0(T7<BU7L
MBTWP(<H)T(T$`XG"`U7HBT78BP"-!`(M)$/D<(E%Y(-%V`3!3=P"BT7DB</!
MRQN+1?"+5=P)T"-%X(M5\(M-W"'*"="-!`.)P@-5[(M%V(L`C00"+21#Y'")
M1>B#1=@$P4W@`HM%Z(G#P<L;BT7<BU7@"=`C1>2+5=R+3>`AR@G0C00#B<(#
M5?"+1=B+`(T$`BTD0^1PB47L@T78!,%-Y`*+1>R)P\'+&XM%X(M5Y`G0(T7H
MBU7@BTWD(<H)T(T$`XG"`U7<BT78BP"-!`(M)$/D<(E%\(-%V`3!3>@"BT7P
MB</!RQN+1>2+5>@)T"-%[(M5Y(M-Z"'*"="-!`.)P@-5X(M%V(L`C00"+21#
MY'")1=R#1=@$P4WL`HM%W(G#P<L;BT7HBU7L"=`C1?"+5>B+3>PAR@G0C00#
MB<(#5>2+1=B+`(T$`BTD0^1PB47@@T78!,%-\`*+1>")P\'+&XM%[(M5\`G0
M(T7<BU7LBTWP(<H)T(T$`XG"`U7HBT78BP"-!`(M)$/D<(E%Y(-%V`3!3=P"
MBT7DB</!RQN+1?"+5=P)T"-%X(M5\(M-W"'*"="-!`.)P@-5[(M%V(L`C00"
M+21#Y'")1>B#1=@$P4W@`HM%Z(G#P<L;BT7<BU7@"=`C1>2+5=R+3>`AR@G0
MC00#B<(#5?"+1=B+`(T$`BTD0^1PB47L@T78!,%-Y`*+1>R)P\'+&XM%X(M5
MY`G0(T7HBU7@BTWD(<H)T(T$`XG"`U7<BT78BP"-!`(M)$/D<(E%\(-%V`3!
M3>@"BT7PB</!RQN+1>2+5>@)T"-%[(M5Y(M-Z"'*"="-!`.)P@-5X(M%V(L`
MC00"+21#Y'")1=R#1=@$P4WL`HM%W(G#P<L;BT7HBU7L"=`C1?"+5>B+3>PA
MR@G0C00#B<(#5>2+1=B+`(T$`BTD0^1PB47@@T78!,%-\`*+1>")P\'+&XM%
M[(M5\`G0(T7<BU7LBTWP(<H)T(T$`XG"`U7HBT78BP"-!`(M)$/D<(E%Y(-%
MV`3!3=P"BT7DB</!RQN+1?"+5=P)T"-%X(M5\(M-W"'*"="-!`.)P@-5[(M%
MV(L`C00"+21#Y'")1>B#1=@$P4W@`HM%Z(G#P<L;BT7<BU7@"=`C1>2+5=R+
M3>`AR@G0C00#B<(#5?"+1=B+`(T$`BTD0^1PB47L@T78!,%-Y`*+1>R)P<')
M&XM%Y(M5Z#'0,T7@C00!B<(#5=R+1=B+`(T$`BTJ/ITUB47P@T78!,%-Z`*+
M1?")P<')&XM%Z(M5[#'0,T7DC00!B<(#5>"+1=B+`(T$`BTJ/ITUB47<@T78
M!,%-[`*+1=R)P<')&XM%[(M5\#'0,T7HC00!B<(#5>2+1=B+`(T$`BTJ/ITU
MB47@@T78!,%-\`*+1>")P<')&XM%\(M5W#'0,T7LC00!B<(#5>B+1=B+`(T$
M`BTJ/ITUB47D@T78!,%-W`*+1>2)P<')&XM%W(M5X#'0,T7PC00!B<(#5>R+
M1=B+`(T$`BTJ/ITUB47H@T78!,%-X`*+1>B)P<')&XM%X(M5Y#'0,T7<C00!
MB<(#5?"+1=B+`(T$`BTJ/ITUB47L@T78!,%-Y`*+1>R)P<')&XM%Y(M5Z#'0
M,T7@C00!B<(#5=R+1=B+`(T$`BTJ/ITUB47P@T78!,%-Z`*+1?")P<')&XM%
MZ(M5[#'0,T7DC00!B<(#5>"+1=B+`(T$`BTJ/ITUB47<@T78!,%-[`*+1=R)
MP<')&XM%[(M5\#'0,T7HC00!B<(#5>2+1=B+`(T$`BTJ/ITUB47@@T78!,%-
M\`*+1>")P<')&XM%\(M5W#'0,T7LC00!B<(#5>B+1=B+`(T$`BTJ/ITUB47D
M@T78!,%-W`*+1>2)P<')&XM%W(M5X#'0,T7PC00!B<(#5>R+1=B+`(T$`BTJ
M/ITUB47H@T78!,%-X`*+1>B)P<')&XM%X(M5Y#'0,T7<C00!B<(#5?"+1=B+
M`(T$`BTJ/ITUB47L@T78!,%-Y`*+1>R)P<')&XM%Y(M5Z#'0,T7@C00!B<(#
M5=R+1=B+`(T$`BTJ/ITUB47P@T78!,%-Z`*+1?")P<')&XM%Z(M5[#'0,T7D
MC00!B<(#5>"+1=B+`(T$`BTJ/ITUB47<@T78!,%-[`*+1=R)P<')&XM%[(M5
M\#'0,T7HC00!B<(#5>2+1=B+`(T$`BTJ/ITUB47@@T78!,%-\`*+1>")P<')
M&XM%\(M5W#'0,T7LC00!B<(#5>B+1=B+`(T$`BTJ/ITUB47D@T78!,%-W`*+
M1>2)P<')&XM%W(M5X#'0,T7PC00!B<(#5>R+1=B+`(T$`BTJ/ITUB47H@T78
M!,%-X`*+1>B)P<')&XM%X(M5Y#'0,T7<C00!B<(#5?"+1=B+`(T$`BTJ/ITU
MB47L@T78!,%-Y`*+1>R)P<')&XM%Y(M5Z#'0,T7@C00!B<(#5=R+1=B+`(T$
M`BTJ/ITUB47P@T78!,%-Z`*+1?")P<')&XM%Z(M5[#'0,T7DC00!B<(#5>"+
M1=B+`(T$`BTJ/ITUB47<@T78!,%-[`*+10B+`(G"`U7<BT4(B1"+10B+0`2)
MP@-5\(M%"(E0!(M%"(M`"(G"`U7LBT4(B5`(BT4(BT`,B<(#5>B+10B)4`R+
M10B+0!")P@-5Y(M%"(E0$('$<`$``%M=PU6)Y8M%",<``2-%9XM%",=`!(FK
MS>^+10C'0`C^W+J8BT4(QT`,=E0R$(M%",=`$/#ATL.+10C'0!0`````BT4(
MQT`8`````(M%",=`7`````!=PU6)Y8/L&(M%"(M`%(M5$,'B`P'0B47PBT4(
MBT`4.T7P=@^+10B+0!B-4`&+10B)4!B+10B+5?")4!2+10B+0!B+51#!ZAV-
M%!"+10B)4!B+10B+0%R%P`^$J0```(M%"(M`7+I`````B=$IP8G(B47TBT7T
M.T40?@:+11")1?2+1?2+50B-2AR+50B+4ER-%!&#[`10_W4,4NB[W?__@\00
MBT7T*440BT7T`44,BT4(BT!<B<(#5?2+10B)4%R+10B+0%R#^$!U9X/L#/]U
M".@O[/__@\00ZRV+10B#P!R#[`1J0/]U#%#H;-W__X/$$(-%#$"#;1!`@^P,
M_W4(Z`#L__^#Q!"#?1`_?\V+11"+50B#PAR#[`10_W4,4N@WW?__@\00BT4(
MBU40B5!<ZP&0R<-5B>7_=0SHQ>O__X/$!(M%#(L`P>@8B,*+10B($(M%"(U0
M`8M%#(L`P>@0B`*+10B-4`*+10R+`,'H"(@"BT4(C5`#BT4,BP"(`HM%"(U0
M!(M%#(M`!,'H&(@"BT4(C5`%BT4,BT`$P>@0B`*+10B-4`:+10R+0`3!Z`B(
M`HM%"(U0!XM%#(M`!(@"BT4(C5`(BT4,BT`(P>@8B`*+10B-4`F+10R+0`C!
MZ!"(`HM%"(U0"HM%#(M`",'H"(@"BT4(C5`+BT4,BT`(B`*+10B-4`R+10R+
M0`S!Z!B(`HM%"(U0#8M%#(M`#,'H$(@"BT4(C5`.BT4,BT`,P>@(B`*+10B-
M4`^+10R+0`R(`HM%"(U0$(M%#(M`$,'H&(@"BT4(C5`1BT4,BT`0P>@0B`*+
M10B-4!*+10R+0!#!Z`B(`HM%"(U0$XM%#(M`$(@"R<-5B>6#[!B+10R+0!2)
M1?"+10R+0!B)1>R+1?#!Z`.#X#^)1?2+10R-4!R+1?2-!`+&`(#_1?2#??0X
M?DFX0````"M%](M5#(U*'(M5](T4$8/L!%!J`%+H.MK__X/$$(/L#/]U#.@6
MZO__@\00BT4,@\`<@^P$:CAJ`%#H%MK__X/$$.LCN#@````K1?2+50R-2AR+
M5?2-%!&#[`10:@!2Z/'9__^#Q!"+1>S!Z!B(PHM%#(A05(M%[,'H$(C"BT4,
MB%!5BT7LP>@(B,*+10R(4%:+1>R(PHM%#(A05XM%\,'H&(C"BT4,B%!8BT7P
MP>@0B,*+10R(4%F+1?#!Z`B(PHM%#(A06HM%\(C"BT4,B%!;@^P(_W4,_W4(
MZ)#]__^#Q!#)PU6)Y8/L&,=%]`````#'1?``````Z/C:__^#[`Q0Z,_:__^#
MQ!")1?"#??``=`B+1?"+`(E%](M%],G#58GE@^P(@^P,:@#H9MS__X/$$(L`
M@^P,4.A(V?__@\00@^P,4.ALV___@\00@^P(4/]U".A=%P``@\00A<`/A8<`
M``"#[`QJ`.@HW/__@\00BP"#[`Q0Z`K9__^#Q!"#[`Q0Z"[;__^#Q!"+0!`E
M`/```#T`0```=#:#[`QJ`.CRV___@\00BP"#[`Q0Z-38__^#Q!"#[`Q0Z/C:
M__^#Q!"+0!`E`/```#T`H```=1N#[`AJ`O]U".@9V?__@\00A<!U![@!````
MZP6X`````,G#58GE5U93@^P\QT7D`````,=%X`````"-5<"[G-H$"+@&````
MB=>)WHG!\Z7'1=@`````QT7<`````.G&````@^P,_W7DZ';>__^#Q!")1>"#
M?>``=`F+1>"*`(3`=1:#[`C_=0C_=>3H;=[__X/$$.F-````@^P(_W4(_W7@
MZ-'9__^#Q!"%P'5X@^P,_W4(Z"_9__^#Q!")PZ%(404(@^P,4.@<V?__@\00
M`<.#[`S_=>#H#-G__X/$$(T$`X/``H/L#%#HFMG__X/$$(E%V(L52%$%"+A)
MV`0(@^P,_W7@4O]U"%#_==CH1M;__X/$((/L"/]UV/]UY.C;W?__@\00_T7<
MBT7<BT2%P(E%Y(M%Y(H`A,`/A2/___^-9?2#Q`!;7E]=PU6)Y5=64X'L/($`
M`(M%"(F%Q'[__V6A%````(E%Y#'`QX4X?___`````,>%-'___P````#'A3!_
M__\`````QX7H?O__'MD$",>%['[__R;9!`C'A?!^__]'V`0(QX7T?O__*]D$
M"(V5T'[__[M,V@0(N`8```")UXG>B<'SI<>%^'[__RS9!`C'A?Q^__\QV00(
MQX4`?___*]D$",>%+'___SK9!`C'A2A___\KV00(QX4D?___`````,>%('__
M_P````#'A1Q___\`````QX4,?___`````(/L#&@QV`0(Z+3<__^#Q!")A3!_
M__^#O3!___\`=#.+A3!___^*`(3`=">#[`S_M3!____HR/W__X/$$(/L#/^U
M,'___^A+V?__@\00Z4X&``#HG?S__XF%('___X.]('___P!U<<>%0'___P``
M``#K/8/L#/^U-'___^A!W/__@\00B84P?___@[TP?___`'07@^P,_[4P?___
MZ/78__^#Q!")A2!_____A4!___^#O2!___\`=1^+A4!___^+A(7X?O__B84T
M?___BX4T?___B@"$P'6;@[T@?___`'4,QX4@?___/]D$".M/BX4@?___B84\
M?___ZS7H1M;__XL0BX4\?___B@`/OL`!P(T$`F:+`"7__P``@^`(A<!U"8N%
M/'___\8`7_^%/'___XN%/'___XH`A,!UO\>%0'___P````#K4H/L#/^U-'__
M_^ALV___@\00B84P?___@[TP?___`'0L@^P,_[4P?___Z+K[__^#Q!"%P'07
M@^P,_[4P?___Z`O8__^#Q!")A3A_____A4!___^#O3A___\`=1^+A4!___^+
MA(70?O__B84T?___BX4T?___B@"$P'6&QX5`?___`````.LR@^P,_[4P?___
MZ%3[__^#Q!"%P'07@^P,_[4P?___Z*77__^#Q!")A3A_____A4!___^#O3A_
M__\`=1^+A4!___^+A(7H?O__B84P?___BX4P?___B@"$P'6F@^P,_[4X?___
MZ)#5__^#Q!")PX/L#/^U+'___^A]U?__@\00`<.#[`S_M2!____H:M7__X/$
M$`'#@^P,_[4H?___Z%?5__^#Q!"-!`,%``0``(F%#'___XN%#'___X/L#%#H
MU]7__X/$$(F%''___XL51%$%"+A&V00(@^P(_[4@?____[4L?___4O^U.'__
M_U#_M1Q____H<=+__X/$((/L"&CM`0``_[4<?___Z(O2__^#Q!"#[`QH3]D$
M".C7V?__@\00B84P?___@[TP?___`'0N@^P,_[4P?___Z(O6__^#Q!")PHN%
MQ'[__XL`@^P(4E#HS=S__X/$$(F%)'___X.])'___P!U#HN%Q'[__XL`B84D
M?___Z+;B__^%P`^%*`(``(/L"&H`_[4D?___Z/?5__^#Q!")A1A___^#O1A_
M__\`#X0"`@``:@)J_VKN_[48?___Z*#2__^#Q!"#[`1J!HV%1'___U#_M1A_
M___H!M/__X/$$(J%1'___X3`#X6O````BH5%?___/$,/A:$```"*A49___\\
M00^%DP```(J%1W___SQ##X6%````BH5(?___/$AU>XJ%27___SQ%=7%J`FK_
M:L;_M1A____H)M+__X/$$(/L!&HIC85$?___4/^U&'___^B,TO__@\00BS5$
M404(NU39!`B#[`S_M1Q____HD-/__X/$$`.%''___X/L#/^U*'___XV51'__
M_U)64U#HW]#__X/$()#I%`(``(/L#(V%1/___U#HBO3__X/$$.L?@^P$_[44
M?___C85$?___4(V%1/___U#HO?3__X/$$(/L!&@`@```C85$?___4/^U&'__
M_^CYT?__@\00B844?___@[T4?___`'^U@^P,_[48?___Z&G3__^#Q!"#[`B-
MA43___]0C4704.CM]O__@\00QX40?___`````.LYBX40?___BD0%T+D`````
MB,&Z8=D$"(N%$'___P'`B<.-1:<!V(/L!%%24.@4T/__@\00_X40?___@[T0
M?___$WZ^QD7/`(LU1%$%"+M4V00(@^P,_[4<?___Z'72__^#Q!`#A1Q___^#
M[`S_M2A___^-5:=25E-0Z,?/__^#Q"#I_0```,>%"'___P````"#[`S_M1Q_
M___H-]+__X/$$(F%!'___X/L"&CXV`0(:&S8!`CH,M?__X/$$.BDS___B<.+
M/411!0B^9MD$"(/L#/^U''___^CYT?__@\00`X4<?___@^P,_[4H?___4U=6
M4.A.S___@\0@ZUR+A01___^+E1Q___^-!`+&``#_A0A____H3,___XG#BSU$
M404(OG+9!`B#[`S_M1Q____HH='__X/$$`.%''___X/L"/^U*'____^U"'__
M_U-75E#H\,[__X/$((/L"&CM`0``_[4<?___Z`K/__^#Q!"#^/]U$.B]SO__
MBP"#^!$/A'G___^#[`C_M1Q___]H,=@$".A5UO__@\00@^P,_[4<?___Z&KW
M__^#Q!"+A1Q___^+5>1E,Q44````=`7HU-'__XUE](/$`%M>7UW#58GE4X/L
M=,=%[`````"#?0@`#X19`0``BT4(B@"$P`^$3P$``(/L#/]U".@YT/__@\00
MB47T@WWT``^%]P```.DP`0``BT7P@\`3@^P(:$?8!`A0Z+#2__^#Q!"%P`^$
MU````(M%\(/`$X/L"&B!V00(4.B1TO__@\00A<`/A+4```"#[`S_=0CH>]#_
M_X/$$(G#BT7P@\`3@^P,4.AGT/__@\00C00#@\`"B47HBT7H@^P,4.COT/__
M@\00B47LBT7PC5`3N(39!`A2_W4(4/]U[.BAS?__@\00BT7L@^P(C56(4E#H
M[@P``(/$$(/X_W0?BT68)0#P```]`$```'40@^P,_W7LZ//^__^#Q!#K#H/L
M#/]U[.C\S___@\00@^P,_W7LZ.[.__^#Q!#'1>P`````ZP&0@^P,_W7TZ);/
M__^#Q!")1?"#??``#X7R_O__@^P,_W7TZ`O0__^#Q!"#[`S_=0CH;=#__X/$
M$.L$D.L!D(M=_,G#58GE@^P8@^P,_W4(Z*#:__^#Q!")1?2#[`S_=?3H4]K_
M_X/$$(E%\.B9W?__A<!T-8-]"`!T+XM%"(H`A,!T)H/L"&@ZV00(_W7PZ,_/
M__^#Q!`[1?!U#H/L#/]U".@C_O__@\00R<-5B>53@^P$@^P,:@#H]M#__X/$
M$(L`@^P,4.C8S?__@\00@^P,4.A\S/__@\00BP"+6`2#[`QJ`.C*T/__@\00
MBP"#[`Q0Z*S-__^#Q!"#[`Q0Z/#,__^#Q!"*`(A#&(/L#&H`Z)[0__^#Q!"+
M`(/L#%#H@,W__X/$$(/L#%#H),S__X/$$(L`BU@$@^P,:@#H<M#__X/$$(L`
M@^P,4.A4S?__@\00@^P,4.BHS/__@\00BP"+0!`E_P$``&:)0QJ#[`QJ`.@]
MT/__@\00BP"#[`Q0Z!_-__^#Q!"#[`Q0Z,/+__^#Q!"+`(M8!(/L#&H`Z!'0
M__^#Q!"+`(/L#%#H\\S__X/$$(/L!&H`:"O9!`A0Z'#/__^#Q!")0QR#[`QJ
M`.C@S___@\00BP"#[`Q0Z,+,__^#Q!"#[`Q0Z&;+__^#Q!"+`(M8!(/L#&H`
MZ+3/__^#Q!"+`(/L#%#HELS__X/$$(/L#%#HNLO__X/$$(L`B4,@@^P,:@#H
MB,___X/$$(L`@^P,4.AJS/__@\00@^P,4.@.R___@\00BP"+6`2#[`QJ`.A<
MS___@\00BP"#[`Q0Z#[,__^#Q!"#[`Q0Z%+.__^#Q!"+`(7`="Z#[`QJ`.@O
MS___@\00BP"#[`Q0Z!',__^#Q!"#[`Q0Z"7.__^#Q!"+`(M`;.L%N`````")
M0R2#[`QJ`.CYSO__@\00BP"#[`Q0Z-O+__^#Q!"#[`Q0Z'_*__^#Q!"+`(M`
M!,=`*`````"#[`QJ`.C&SO__@\00BP"#[`Q0Z*C+__^#Q!"#[`Q0Z$S*__^#
MQ!"+`(M`!,=`+`````"#[`QJ`.B3SO__@\00BP"#[`Q0Z'7+__^#Q!"#[`Q0
MZ!G*__^#Q!"+`(M8!(/L#&H`Z&?.__^#Q!"+`(/L#%#H2<O__X/$$(/L#%#H
M#<[__X/$$(L`B4,PBUW\R<-5B>6#[`B#[`QJ`.@PSO__@\00BP"#[`Q0Z!++
M__^#Q!"#[`AJ_U#H5,O__X/$$(/L#&H`Z`?.__^#Q!"+`(/L#%#HZ<K__X/$
M$(/L!&H`:"G+!`A0Z#;.__^#Q!#)PU6)Y593@^P@QT7@`````(/L#&H`Z,C-
M__^#Q!"+`(/L#%#HJLK__X/$$(/L#%#H'LO__X/$$,8``8/L#&A0V`0(Z+?0
M__^#Q!")1=R#?=P`=!.+1=R*`#PQ=0J+1=Q`B@"$P'0%Z++7__^#[`QJ`.AM
MS?__@\00BP"#[`Q0Z$_*__^#Q!!J"VH!:(K9!`A0Z/W)__^#Q!")1?2#??0`
M#X0G`0``BT7TBT`,BT`8B47PQT7D`0```.FM````BT7DC5C_@^P,:@#H%<W_
M_X/$$(L`@^P,4.CWR?__@\00:@!3_W7P4.AHR___@\00B47L@WWL``^$@```
M`(M%[(L`BT`()0`$``"%P'0*BT7LBP"+0`SK+HM%[(L8@^P,:@#HOLS__X/$
M$(L`@^P,4.B@R?__@\00:@)J`%-0Z`+-__^#Q!"+%8Q1!0B+3>3!X0(!RHL2
M@^P(4%+HI<S__X/$$(7`=1G_1>#_1>2AB%$%"#E%Y`^,1?___^L$D.L!D*&(
M404(2#M%X'5#QT7D`0```.LP@^P,:@#H1LS__X/$$(L`@^P,4.@HR?__@\00
M@^P(_W7P4.C)R/__@\00B47H_T7DH8A1!0@Y1>1\QH/L#&H`Z`S,__^#Q!"+
M`(/L#%#H[LC__X/$$&H%:@%HC]D$"%#HG,C__X/$$(E%](-]]`!T>8M%](M`
M#(L8@^P,:@#HSLO__X/$$(L`@^P,4.BPR/__@\00@^P$:)'9!`A34.A^R/__
M@\00BT7TBT`,BP"+0`@E``!``(7`=#"+1?2+0`R+&(/L#&H`Z(7+__^#Q!"+
M`(/L#%#H9\C__X/$$(/L"%-0Z#K*__^#Q!"#[`QJ`.A=R___@\00BP"#[`Q0
MZ#_(__^#Q!!J!6H!:);9!`A0Z.W'__^#Q!")1?2#??0`#X2-````QT78````
M`(/L#&@ZV`0(Z#7.__^#Q!")1=B#?=@`=#6+1?2+0`R+&(/L#&H`Z/O*__^#
MQ!"+`(/L#%#HW<?__X/$$(/L!/]UV%-0Z*W'__^#Q!#K.*&,404(BS"+1?2+
M0`R+&(/L#&H`Z+_*__^#Q!"+`(/L#%#HH<?__X/$$(/L!%934.@+S/__@\00
M@^P,:@#HELK__X/$$(L`@^P,4.AXQ___@\00@^P,4.CLQ___@\00Q@``@^P,
M:@#H;,K__X/$$(L`@^P,4.A.Q___@\00@^P,4.B"RO__@\00QP``````@^P,
M:#'8!`CH6,W__X/$$*.$404(H811!0B%P`^%YP```*&,404(@^P,4.B<[___
M@\00HX11!0B+'8Q1!0B+1?2+0`R+`(M`""4`!```A<!T#8M%](M`#(L`BT`,
MZS&+1?2+0`R+,(/L#&H`Z-C)__^#Q!"+`(/L#%#HNL;__X/$$&H":@!64.@<
MRO__@\00@^P(4U#HO\?__X/$$(E%Y(M%](M`#(L`BT`()0`$``"%P'0-BT7T
MBT`,BP"+0`SK,8M%](M`#(L8@^P,:@#H=LG__X/$$(L`@^P,4.A8QO__@\00
M:@)J`%-0Z+K)__^#Q!"+%8Q1!0B+$O]UY%!2:)C9!`CHD,C__Z&$404(@^P(
M:.T!``!0Z.W$__^#Q!")1>2#?>0`="B#?>01="*#?>3_=!R+%811!0BAC%$%
M"(L`_W7D4E!HR-D$".A)R/__C67X@\0`6UY=PU6)Y8/L"(/L#&H`Z-_(__^#
MQ!"+`(/L#%#HP<7__X/$$(/L#%#H[<G__X/$$(/L#&H`Z+C(__^#Q!"+`(/L
M#%#HFL7__X/$$(/L"&H`:"O9!`AH*]D$"&A/S@0(:!;:!`A0Z%C&__^#Q"#)
MPXU,)`2#Y/#_<?Q5B>5348/L((G+@^P$C4,(4(U#!%")V%#H/,C__X/$$(/L
M!&@@F`0(:""8!`AH\)D$".B2`@``@\00@^P,:@#H5<7__X/$$(H`A,!U6.@W
MQ?__HX!1!0BA@%$%"(7`=0J#[`QJ`>A/R/__H8!1!0B#[`Q0Z.'%__^#Q!"#
M[`QJ`.CTQ___@\00BP"#[`Q0Z-;$__^#Q!"#[`Q0Z#K'__^#Q!#&``"#[`QJ
M`.C*Q___@\00BP"#[`Q0Z*S$__^#Q!"#[`Q0Z,#'__^#Q!"*$(/*`H@0@^P,
M:@#HG,?__X/$$(L`@^P,4.A^Q/__@\00@^P,4.B2Q___@\00BA"#R@&($(L#
M@\`%B47<9@]N1=QF#]9%X-]MX-GNWL'=!;C:!`C9R=_IW=@/E\"$P'0-@^P,
M:&11!0CHC\;__XL#@\`%P>`"@^P,4.B>QO__@\00HXQ1!0BAC%$%"(M3!(L2
MB1"AC%$%"(/`!,<`*]H$"*&,404(@\`(QP#@V@0(QP6(404(`P```*&,404(
MBQ6(404(P>("`=#'`"[:!`BAB%$%"$"CB%$%",=%\`$```#K)HL5C%$%"*&(
M404(`T7P2,'@`@'"BT,$BTWPP>$"`<B+`(D"_T7PBP,Y1?!\TZ&,404(BPN+
M%8A1!0B-%!%*P>("`=#'``````"+%8Q1!0B+"Z&(404(C00!C4C_H8!1!0B#
M[`QJ`%)1:$'3!`A0Z#?"__^#Q"")1?2#??0`=12A@%$%"(/L#%#HS<+__X/$
M$(E%]*&`404(@^P,4.C)Q/__@\00@^P,:&#8!`CH-<G__X/$$(7`=3BAA%$%
M"(7`=16#[`QH,=@$".@8R?__@\00HX11!0BAA%$%"(7`=!&AA%$%"(/L#%#H
M;O3__X/$$*&`404(@^P,4.B<P?__@\00Z%3#__^+1?2-9?B#Q`!96UV-8?S#
MD)"0D%6)Y5/H`````%N!PVMY``"+@TP!``"+31!0BU4,BT4(45)0Z/C!__^+
M7?S)PY"0D%6)Y5W#C70F`(V\)P````!5B>575E.#[!SH`````%N!PR9Y``"+
M?0CHD\#__XV#\/[__XV3\/[__RG0P?@"B47D=!\Q]HUV`(M5$(M%#%%24%?_
ME+/P_O__1H/$$#MUY'+FC67T6UY?7<.0D)"0D)!5B>53Z`````!;@</+>```
MBU4,BT4(4E!J`^@AP?__BUW\R<.0D)"0D)"0D)"0D)!5B>53Z`````!;@<.;
M>```BU4,BT4(4E!J`^@1PO__BUW\R<.0D)"0D)"0D)"0D)!5B>53@^P$H>1.
M!0B#^/]T$[OD3@4(9I"#ZP3_T(L#@_C_=?186UW#58GE4X/L!.@`````6X'#
M0'@``.@0Q?__65O)PP`````````````````````````````````````#````
M`0`"`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`+W!R
M;V,O<V5L9B]E>&4`+P`Z`"]P<F]C+R5I+R5S`&5X90!005)?5$5-4`!005)?
M4%)/1TY!344`+@`E<R5S)7,`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!
M4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?
M5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#
M3$5!3CT`,0```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``!#
M.EQ414U0`"]T;7```%5315(`55-%4DY!344`<&%R+0!365-414T`)7,E<R5S
M)7,`4$%42``E<V-A8VAE+25S)7,`)3`R>``E<W1E;7`M)74E<P`E<W1E;7`M
M)74M)74E<P`N+@`E<R\E<P!!4D=6`!@`<&5R;``P`"5S.B!E>&5C=71I;VX@
M;V8@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("T@86)O<G1I;F<@=VET:"`E:2X*`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"UE
M`"TM`%1-4$1)4@!414U01$E2`%1%35``5$U0`````,'8!`@QV@0(.-H$"$#:
M!`A%V@0(*]D$"$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%4
M2`!$64Q$7TQ)0E)!4EE?4$%42```9-H$"'3:!`A\V@0(3]D$"(G:!`@KV00(
M````````@/___\]!<&%R+G!L```````````````````````````````````C
M(2]U<W(O8FEN+W!E<FP*"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I
M<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M
M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34Y"@IM>2`H)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.
M?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T
M;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@
M("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@
M("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`[
M"B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E
M<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN
M9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N
M;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@
M("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L
M;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@
M97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A
M8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S
M(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@
M("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@
M<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L
M96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@
M("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@
M("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T
M;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@
M("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@
M(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*
M("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU
M;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E
M;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D
M=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N
M86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ
M0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES
M=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*
M("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%
M3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T[
M"GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T
M92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV
M;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S
M971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E
M>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T
M82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R
M(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E
M96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S
M="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L
M("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L
M("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B
M=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C
M('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@
M>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M
M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG
M(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH
M/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F
M:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@
M(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@
M("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@
M("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F
M:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@
M("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@
M;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@
M("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@
M("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A
M<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA
M;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N
M86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@
M("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D
M;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E
M<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A
M=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@
M("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@
M("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@
M('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@
M?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@
M;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M
M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@
M("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E
M<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O
M7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S
M=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?
M;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T
M=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N
M86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL
M96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@
M("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N
M<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I
M('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@
M("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@
M("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P
M96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@
M8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@
M('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T
M(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L
M;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S
M:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97([
M"B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE
M879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y
M(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I
M<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN
M"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER
M95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C
M=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN
M<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@
M("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I
M;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@
M("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA
M;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["@HC($1O
M;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE
M<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M
M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@
M("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A
M<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R
M"B`@("`I.PH*("`@(&UY($!A9&1?=&]?:6YC.PH@("`@=VAI;&4@*$!!4D=6
M*2!["B`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI
M*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@
M("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D,CL*("`@("`@("!]"B`@("`@
M("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("!E=F%L(")U<V4@
M)#(B.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@
M("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("!]"B`@
M("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`D;W5T(#T@
M)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@
M("`@("`@("`@)&)U;F1L92`]("=S:71E)SL*("`@("`@("!]"B`@("`@("`@
M96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`D8G5N9&QE(#T@)V%L
M;"<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@
M("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("!]"B`@("`@("`@96QS:68@
M*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("1C
M86-H95]N86UE(#T@)#(["B`@("`@("`@?0H*("`@("`@("!S:&EF="A`05)'
M5BD["@H@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@
M("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@
M("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0[
M"B`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PH@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PH@("`@("`@("`@("!E>&ET.PH@("`@("`@('T*("`@('T*"B`@
M("!U;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"@HC(%A86"`M+2!A9&0@
M+2UP87(M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M
M3RD@:&%N9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO
M8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I
M;C,R)SL*("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I
M<F4@07)C:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`
M05)'5BD["B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2![
M"B`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO
M="!F:6YD("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@
M("`@("!B;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@
M*0H@("`@("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2([
M"B`@("!]"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@
M86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*
M("`@("`@("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@
M("`@("1M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@
M("`C($]P96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L
M("0O(#T@7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P
M96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@
M8FEN;6]D92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@
M9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@
M("!#<F5A=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN
M;6]D92@D9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD
M9&%T85]P;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@
M)&QO861E<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@
M("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I
M"B`@("!]"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"B`@("`@("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@
M("`D=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@
M("!M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"B`@("`@("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L
M(CL*("`@("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@
M("`@("1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H
M)&QO861E<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R
M:71E(&)U;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@
M("`@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@
M("`@("!R97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O
M<G0@>PH@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@
M("`@("`@?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@
M?2!G<F5P('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@
M("`@("`@("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L
M:6)E>'!]*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(&EF("@D0V]N9FEG
M>U]D96QI;7T@97$@)UQ<)RD@>R!S>UQ<?7LO?6<@9F]R($!I;F,@?0H*("`@
M("`@("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y
M,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN
M+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@
M("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R
M87-P(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G
M;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA
M<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@
M("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N
M9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD
M7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N
M.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@
M("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<
M421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@
M("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N
M>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T
M<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@
M("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D
M8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@
M("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@
M1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@
M("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T
M(%A33&]A9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@
M("`@("`@("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S
M<R`K+BHO9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H
M)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@
M("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*
M("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S
M('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@
M("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M
M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@
M("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F
M:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@
M("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2
M(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A
M9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@
M>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@
M(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI
M.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@
M("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;
M7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@
M("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@
M;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@
M("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@
M0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL
M93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U
M;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*
M<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I
M<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I
M;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI
M;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@
M<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97([
M"B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@
M("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*
M("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@
M("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2
M.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I
M<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(&5V
M86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PI]"@HC(%1H
M92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT
M;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!4
M96UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*
M("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@
M("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@
M("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@
M+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N
M86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O
M<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@
M)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O
M7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E
M;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P
M-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N
M("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D
M9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L
M(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@
M("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@
M('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@
M/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]
M"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@
M("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U
M9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@
M("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)3
M24].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@
M97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@
M("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I
M9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X
M+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E
M*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,
M14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@
M("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A
M<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@
M("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS
M92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@
M)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA
M;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F
M:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3
M971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@
M>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6
M>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE
M(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H
M)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?
M5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R
M;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@
M,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@
M("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@
M("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M
M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R
M;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*
M("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@
M(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E
M;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@
M("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U
M8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6
M>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA
M8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z
M("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@
M.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D
M96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*
M?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE4
M24%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS
M92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*
M"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.
M5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@
M0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%2
M7U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@
M('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI
M('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@
M*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]
M("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*
M"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO
M9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@
M(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN
M:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@
M("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI
M8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I
M.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P
M86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR
M97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!
M4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R
M;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["@HQ.PH*(VQI;F4@,3`P,@H*7U]%3D1?7PH````!&P,[,`````4`
M```PHO__3````&"B__]L````<*+__X@```#0HO__K`````"C___,````%```
M```````!>E(``7P(`1L,!`2(`0``'````!P```#<H?__+0````!!#@A"A0(-
M!4V#`U,N$``8````/````.RA__\%`````$$."$*%`@T%````(````%@```#@
MH?__6@````!!#@A"A0(-!5*#!88$AP-M+A``'````'P````<HO__)`````!!
M#@A"A0(-!4V#`THN#``<````G````"RB__\D`````$$."$*%`@T%38,#2BX,
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/__
M__\`````_____P```````````0````$````!````L@(```$```"]`@```0``
M`,<"```!````%@,```$```!)!```#````'"7!`@-````J-<$"`0```"L@00(
M]?[_;P2%!`@%````C(T$"`8```!<A@0("@```-T%```+````$````!4`````
M`````P```/1/!0@"````>`(``!0````1````%P```/B4!`@1````X)0$"!(`
M```8````$P````@```#^__]O4)0$"/___V\"````\/__;VJ3!`@`````````
M````````````````````````````````````````````````````````````
M^$X%"```````````MI<$",:7!`C6EP0(YI<$"/:7!`@&F`0(%I@$"":8!`@V
MF`0(1I@$"%:8!`AFF`0(=I@$"(:8!`B6F`0(II@$"+:8!`C&F`0(UI@$".:8
M!`CVF`0(!ID$"!:9!`@FF00(-ID$"$:9!`A6F00(9ID$"':9!`B&F00(EID$
M"*:9!`BVF00(QID$"-:9!`CFF00(]ID$"`::!`@6F@0()IH$"#::!`A&F@0(
M5IH$"&::!`AVF@0(AIH$")::!`BFF@0(MIH$",::!`C6F@0(YIH$"/::!`@&
MFP0(%IL$"":;!`@VFP0(1IL$"%:;!`AFFP0(=IL$"(:;!`B6FP0(IIL$"+:;
M!`C&FP0(UIL$".:;!`CVFP0(!IP$"!:<!`@FG`0(-IP$"$:<!`A6G`0(9IP$
M"':<!`B&G`0(EIP$"```````````'=@$"!_8!`C_____P-H$"&U9``!'0T,Z
M("A58G5N='4@-"XT+C$M-'5B=6YT=30I(#0N-"XQ`$=#0SH@*%5B=6YT=2`T
M+C0N,2TT=6)U;G1U-BD@-"XT+C$``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E
M+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM
M`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN
M`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA;6EC`"YG
M;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````
M```````````````````````````````````````+`````0````(```!4@00(
M5`$``!,```````````````$`````````$P````<````"````:($$"&@!```@
M```````````````$`````````"$````'`````@```(B!!`B(`0``)```````
M````````!``````````X````!0````(```"L@00(K`$``%@#```&````````
M``0````$````-````/;__V\"````!(4$"`0%``!8`0``!@`````````$````
M!````#X````+`````@```%R&!`A<!@``,`<```<````!````!````!````!&
M`````P````(```",C00(C`T``-T%``````````````$`````````3@```/__
M_V\"````:I,$"&H3``#F````!@`````````"`````@```%L```#^__]O`@``
M`%"4!`A0%```D`````<````"````!`````````!J````"0````(```#@E`0(
MX!0``!@````&``````````0````(````<P````D````"````^)0$"/@4``!X
M`@``!@````T````$````"````'P````!````!@```'"7!`AP%P``,```````
M````````!`````````!W`````0````8```"@EP0(H!<````%````````````
M``0````$````@@````$````&````H)P$"*`<```(.P`````````````0````
M`````(@````!````!@```*C7!`BH5P``'```````````````!`````````".
M`````0````(```#@UP0(X%<``&Y<`````````````"``````````E@````$`
M```"````4#0%"%"T```T```````````````$`````````*0````!`````@``
M`(0T!0B$M```O```````````````!`````````"N`````0````,```#D3@4(
MY+X```@```````````````0`````````M0````$````#````[$X%".R^```(
M```````````````$`````````+P````!`````P```/1.!0CTO@``!```````
M````````!`````````#!````!@````,```#X3@4(^+X``/@````'````````
M``0````(````R@````$````#````\$\%"/"_```$```````````````$````
M!````,\````!`````P```/1/!0CTOP``2`$`````````````!`````0```#8
M`````0````,````\404(/,$``!P```````````````0`````````W@````@`
M```#````8%$%"%C!``!$$``````````````@`````````.,````!````,```
M``````!8P0``1@```````````````0````$````!`````P``````````````
8GL$``.P```````````````$`````````
